@@ -346,10 +346,10 @@ def _get_file_text(context, path, content):
 def _get_any(context, path, content, type, mimetype, format, decode):
     method = 'GET' if content else 'HEAD'
     key = _key(context, path)
-    response = _get_object(context, context.s3_bucket, key)
-
-    file_bytes = response.Body
-    last_modified_str = response.LastModified
+    response = yield _get_object(context, context.s3_bucket, key)
+    print(response)
+    file_bytes = response['Body']
+    last_modified_str = response['LastModified']
     last_modified = datetime.datetime.strptime(
         last_modified_str, "%a, %d %b %Y %H:%M:%S GMT")
     return {
@@ -467,7 +467,8 @@ def _save_chunk(context, chunk, content_bytes, path, type, mimetype):
 def _save_bytes(context, content_bytes, path, type, mimetype):
     object_name = _key(context, path)
     response = _put_object(context, context.s3_bucket, content_bytes, object_name)
-
+    print("put obj save bytes")
+    print(response)
     # last_modified_str = response.headers['Date']
     last_modified = f"{datetime.datetime.now():%a, %d %b %Y %H:%M:%S GMT}"
     return _saved_model(path, type, mimetype, last_modified)
@@ -737,7 +738,7 @@ def _list_keys(context, key_prefix, delimiter):
             for item in response['Contents']:
                 key = item['Key']
                 last_modified_str = item['LastModified']
-                if isinstance(last_modified_str, str):
+                if not isinstance(last_modified_str, str):
                     last_modified = f"{datetime.datetime.now():%a, %d %b %Y %H:%M:%S GMT}"
                 else:
                     last_modified = datetime.datetime.strptime(
